==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/MotoristProvider_WSOUIService.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import fr.mines_albi.nuclearcrisisevent.provider.MotoristProvider;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/v3/./motoristProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	name = "motoristProvider")
public class MotoristProvider_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "motoristProvider");
	public final static QName MotoristProviderPort = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "motoristProvider");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/v3/motoristProvider.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/v3/motoristProvider.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public MotoristProvider_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "motoristProviderPort")
	public MotoristProvider getMotoristProviderPort() {
	    return super.getPort(MotoristProviderPort, MotoristProvider.class);
	}
	
	
	@WebEndpoint(name = "motoristProviderPort")
	public MotoristProvider getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(MotoristProviderPort, MotoristProvider.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}

==> crisis-management-resources-v0.4-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/MotoristProvider_WSOUIService.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import fr.mines_albi.nuclearcrisisevent.provider.MotoristProvider;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/management/generated/./motoristProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	name = "motoristProvider")
public class MotoristProvider_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "motoristProvider");
	public final static QName MotoristProviderPort = new QName("http://www.mines-albi.fr/nuclearcrisisevent/provider", "motoristProvider");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/management/generated/motoristProvider.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/management/generated/motoristProvider.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public MotoristProvider_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "motoristProviderPort")
	public MotoristProvider getMotoristProviderPort() {
	    return super.getPort(MotoristProviderPort, MotoristProvider.class);
	}
	
	
	@WebEndpoint(name = "motoristProviderPort")
	public MotoristProvider getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(MotoristProviderPort, MotoristProvider.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}
